@@ -26,3 +26,11 @@ class Circuit():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, Circuit) and (
+            self.circuit_id == __o.circuit_id and
+            self.url == __o.url and
+            self.circuit_name == __o.circuit_name and
+            self.location == __o.location
+        )
