@@ -24,3 +24,11 @@ class Constructor():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, Constructor) and (
+            self.constructor_id == __o.constructor_id and
+            self.url == __o.url and
+            self.name == __o.name and
+            self.nationality == __o.nationality
+        )
