@@ -32,3 +32,13 @@ class DriverStanding():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, DriverStanding) and (
+            self.position == __o.position and
+            self.position_text == __o.position_text and
+            self.points == __o.points and
+            self.wins == __o.wins and
+            self.driver == __o.driver and
+            self.constructors == __o.constructors
+        )
