@@ -28,3 +28,11 @@ class FastestLap():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, FastestLap) and (
+            self.rank == __o.rank and
+            self.lap == __o.lap and
+            self.time == __o.time and
+            self.average_speed == __o.average_speed
+        )
