@@ -59,3 +59,23 @@ class Race():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, Race) and (
+            self.season == __o.season and
+            self.round_no == __o.round_no and
+            self.url == __o.url and
+            self.race_name == __o.race_name and
+            self.circuit == __o.circuit and
+            self.date == __o.date and
+            self.results == __o.results and
+            self.first_practice == __o.first_practice and
+            self.second_practice == __o.second_practice and
+            self.third_practice == __o.third_practice and
+            self.sprint == __o.sprint and
+            self.sprint_results == __o.sprint_results and
+            self.qualifying == __o.qualifying and
+            self.qualifying_results == __o.qualifying_results and
+            self.pit_stops == __o.pit_stops and
+            self.laps == __o.laps
+        )
