@@ -52,3 +52,21 @@ class Result():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, Result) and (
+            self.number == __o.number and
+            self.position == __o.position and
+            self.position_text == __o.position_text and
+            self.points == __o.points and
+            self.driver == __o.driver and
+            self.constructor == __o.constructor and
+            self.grid == __o.grid and
+            self.laps == __o.laps and
+            self.status == __o.status and
+            self.time == __o.time and
+            self.fastest_lap == __o.fastest_lap and
+            self.qual_1 == __o.qual_1 and
+            self.qual_2 == __o.qual_2 and
+            self.qual_3 == __o.qual_3
+        )
