@@ -28,3 +28,11 @@ class StandingsList():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, StandingsList) and (
+            self.season == __o.season and
+            self.round_no == __o.round_no and
+            self.driver_standings == __o.driver_standings and
+            self.constructor_standings == __o.constructor_standings
+        )
