@@ -22,3 +22,10 @@ class Timing():
     def __repr__(self) -> str:
         members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
         return f"{type(self).__name__}({members})"
+
+    def __eq__(self, __o: object) -> bool:
+        return isinstance(__o, Timing) and (
+            self.driver_id == __o.driver_id and
+            self.position == __o.position and
+            self.time == __o.time
+        )
